package RevML::Web::DBI;

=head1 NAME

RevML::Web::DBI -- Database abstraction layer of RevML::Web

=cut

use strict;
use base 'Class::DBI';

1;

=head1 COPYRIGHT

Copyright by gugod@gugod.org.

=cut

__END__
